@@ -12,7 +12,10 @@ class Solver(Rates):
     def __init__(
         self,
         time_span=None,
-        **kwargs,
+        do_coag=1,
+        do_cond=1,
+        do_nucl=1,
+        **kwargs
     ):
         """ constructor
         """
@@ -22,6 +25,9 @@ class Solver(Rates):
             raise ValueError("You must provide a time span!")
 
         self.time_span = time_span
+        self.do_coag = do_coag
+        self.do_cond = do_cond
+        self.do_nucl = do_nucl
 
     def _ode_func(self, _nums, _,):
         """ ode_func
@@ -32,7 +38,11 @@ class Solver(Rates):
             _nums*self.particle_distribution.u
         )
 
-        return self.sum_rates().m
+        return self.sum_rates(
+            coagulation=self.do_coag,
+            condensation=self.do_cond,
+            nucleation=self.do_nucl,
+        ).m
 
     def solution(self):
         """ solve the equation
