@@ -8,18 +8,18 @@ from particula.util.dynamic_viscosity import dyn_vis
 
 
 def pam(
-    rad=None,
+    radius=None,
     scf_val=None,
     vis_val=None,
     **kwargs
 ):
     """ particle aerodynamic mobility
     """
-    rad = in_radius(rad)
+    rad = in_radius(radius)
     scf_val = in_scalar(
-        scf_val) if scf_val is not None else scf(**kwargs)
+        scf_val) if scf_val is not None else scf(radius=rad, **kwargs)
     vis_val = in_viscosity(
-        vis_val) if vis_val is not None else dyn_vis(**kwargs)
+        vis_val) if vis_val is not None else dyn_vis(radius=rad, **kwargs)
 
     return (
         scf_val / (3 * np.pi * vis_val * rad * 2)
